@@ -14,11 +14,11 @@ typedef Eo Efl_Ui_Focus_Manager_Window_Root;
 
 #endif
 /**
- * @brief A interface to indicate the end of a focus chain.
+ * @brief An interface to indicate the end of a focus chain.
  *
- * Focusmanagers are ensuring that if they give focus to something, that they
- * are registered in the upper focus manager. The most upper focus manager does
- * not need to do that, and can implement this interface to indicate that.
+ * Focus managers are ensuring that if they give focus to something, that is
+ * registered in the upper focus manager. The uppermost focus manager does not
+ * need to do that, and can implement this interface to indicate so.
  *
  * @since 1.22
  *
@@ -26,6 +26,6 @@ typedef Eo Efl_Ui_Focus_Manager_Window_Root;
  */
 #define EFL_UI_FOCUS_MANAGER_WINDOW_ROOT_INTERFACE efl_ui_focus_manager_window_root_interface_get()
 
-EWAPI const Efl_Class *efl_ui_focus_manager_window_root_interface_get(void);
+EWAPI const Efl_Class *efl_ui_focus_manager_window_root_interface_get(void) EINA_CONST;
 
 #endif
