@@ -13,18 +13,18 @@ typedef Eo Efl_Ui_Win;
 
 #ifdef EFL_BETA_API_SUPPORT
 /**
- * @brief Defines the types of window that can be created
+ * @brief Defines the types of window that can be created.
  *
  * These are hints set on a window so that a running Window Manager knows how
  * the window should be handled and/or what kind of decorations it should have.
  *
  * Currently, only the X11 backed engines use them.
  *
- * @ingroup Efl_Ui
+ * @ingroup Efl_Ui_Win_Type
  */
 typedef enum
 {
-  EFL_UI_WIN_TYPE_UNKNOWN = -1 /* +1 */, /**< Default, unknown, type */
+  EFL_UI_WIN_TYPE_UNKNOWN = -1 /* +1 */, /**< Default, unknown type. */
   EFL_UI_WIN_TYPE_BASIC, /**< A normal window. Indicates a normal, top-level
                           * window. Almost every window will be created with
                           * this type. */
@@ -34,31 +34,33 @@ typedef enum
   EFL_UI_WIN_TYPE_DOCK, /**< The window is used as a dock or panel. Usually
                          * would be kept on top of any other window by the
                          * Window Manager. */
-  EFL_UI_WIN_TYPE_TOOLBAR, /**< The window is used to hold a floating toolbar,
-                            * or similar. */
-  EFL_UI_WIN_TYPE_MENU, /**< Similar to @.toolbar. */
+  EFL_UI_WIN_TYPE_TOOLBAR, /**< The window is used to hold a floating toolbar or
+                            * similar. */
+  EFL_UI_WIN_TYPE_MENU, /**< Similar to @ref EFL_UI_WIN_TYPE_TOOLBAR. */
   EFL_UI_WIN_TYPE_UTILITY, /**< A persistent utility window, like a toolbox or
                             * palette. */
   EFL_UI_WIN_TYPE_SPLASH, /**< Splash window for a starting up application. */
   EFL_UI_WIN_TYPE_DROPDOWN_MENU, /**< The window is a dropdown menu, as when an
-                                  *  entry in a menubar is clicked. This hint
-                                  * exists for completion only, as the EFL way
-                                  * of implementing a menu would not normally
-                                  * use a separate window for its contents. */
-  EFL_UI_WIN_TYPE_POPUP_MENU, /**< Like @.dropdown_menu, but for the menu
-                               * triggered by right-clicking an object. */
+                                  *  entry in a menu bar is clicked. This hint
+                                  * exists for completeness' sake, as the EFL
+                                  * way of implementing a menu would not
+                                  * normally use a separate window for its
+                                  * contents. */
+  EFL_UI_WIN_TYPE_POPUP_MENU, /**< Like @ref EFL_UI_WIN_TYPE_DROPDOWN_MENU, but
+                               * for the menu triggered by right-clicking an
+                               * object. */
   EFL_UI_WIN_TYPE_TOOLTIP, /**< The window is a tooltip. A short piece of
                             * explanatory text that typically appear after the
                             * mouse cursor hovers over an object for a while.
-                            * Typically not very commonly used in the EFL. */
+                            * Not commonly used in the EFL. */
   EFL_UI_WIN_TYPE_NOTIFICATION, /**< A notification window, like a warning about
                                  * battery life or a new E-Mail received. */
   EFL_UI_WIN_TYPE_COMBO, /**< A window holding the contents of a combo box. Not
-                          * usually used in the EFL. */
-  EFL_UI_WIN_TYPE_DND,
-  EFL_UI_WIN_TYPE_INLINED_IMAGE,
-  EFL_UI_WIN_TYPE_SOCKET_IMAGE,
-  EFL_UI_WIN_TYPE_FAKE,
+                          * commonly used in the EFL. */
+  EFL_UI_WIN_TYPE_DND, /**< Internal use. */
+  EFL_UI_WIN_TYPE_INLINED_IMAGE, /**< Internal use. */
+  EFL_UI_WIN_TYPE_SOCKET_IMAGE, /**< Internal use. */
+  EFL_UI_WIN_TYPE_FAKE, /**< Internal use. */
   EFL_UI_WIN_TYPE_NAVIFRAME_BASIC = 17 /**< Used for naviframe style replacement
                                         * with a back button instead of a close
                                         * button. */
@@ -72,7 +74,7 @@ typedef enum
  * When the application window is being managed by Illume it may request any of
  * the following layouts for the virtual keyboard.
  *
- * @ingroup Efl_Ui
+ * @ingroup Efl_Ui_Win_Keyboard_Mode
  */
 typedef enum
 {
@@ -95,51 +97,59 @@ typedef enum
 } Efl_Ui_Win_Keyboard_Mode;
 #endif /* EFL_BETA_API_SUPPORT */
 
-/** Defines the type indicator that can be shown
+/** Defines the type indicator that can be shown.
  *
  * @since 1.22
  *
- * @ingroup Efl_Ui
+ * @ingroup Efl_Ui_Win_Indicator_Mode
  */
 typedef enum
 {
-  EFL_UI_WIN_INDICATOR_MODE_OFF = 0, /**< Request to deactivate the indicator */
+  EFL_UI_WIN_INDICATOR_MODE_OFF = 0, /**< Request to deactivate the indicator.
+                                      *
+                                      * @since 1.22 */
   EFL_UI_WIN_INDICATOR_MODE_BG_OPAQUE, /**< The indicator icon is opaque, as is
                                         * the indicator background. The content
                                         * of window is located at the end of
                                         * the indicator. The area of indicator
-                                        * and window content are not overlapped
-                                        */
+                                        * and window content are not
+                                        * overlapped.
+                                        *
+                                        * @since 1.22 */
   EFL_UI_WIN_INDICATOR_MODE_BG_TRANSPARENT, /**< The icon of indicator is
                                              * opaque, but the background is
                                              * transparent. The content of
                                              * window is located under the
                                              * indicator in Z-order. The area
                                              * of indicator and window content
-                                             * are overlapped */
+                                             * are overlapped.
+                                             *
+                                             * @since 1.22 */
   EFL_UI_WIN_INDICATOR_MODE_HIDDEN /**< The indicator is hidden so user can see
                                     * only the content of window such as in
                                     * video mode. If user flicks the upper side
                                     * of window, the indicator is shown
-                                    * temporarily. */
+                                    * temporarily.
+                                    *
+                                    * @since 1.22 */
 } Efl_Ui_Win_Indicator_Mode;
 
 #ifdef EFL_BETA_API_SUPPORT
-/** Defines the mode of a modal window
+/** Defines the mode of a modal window.
  *
- * @ingroup Efl_Ui
+ * @ingroup Efl_Ui_Win_Modal_Mode
  */
 typedef enum
 {
-  EFL_UI_WIN_MODAL_MODE_NONE = 0, /**< The window is not modal window. */
-  EFL_UI_WIN_MODAL_MODE_MODAL /**< The window is modal window. */
+  EFL_UI_WIN_MODAL_MODE_NONE = 0, /**< The window is not a modal window. */
+  EFL_UI_WIN_MODAL_MODE_MODAL /**< The window is a modal window. */
 } Efl_Ui_Win_Modal_Mode;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_BETA_API_SUPPORT
 /** Defines the mode of a urgent window.
  *
- * @ingroup Efl_Ui
+ * @ingroup Efl_Ui_Win_Urgent_Mode
  */
 typedef enum
 {
@@ -149,7 +159,7 @@ typedef enum
 #endif /* EFL_BETA_API_SUPPORT */
 
 /**
- * @brief Define the move or resize mode of window.
+ * @brief Define the move or resize mode of a window.
  *
  * The user can request the display server to start moving or resizing the
  * window by combining these modes. However only limited combinations are
@@ -161,25 +171,34 @@ typedef enum
  *
  * @since 1.22
  *
- * @ingroup Efl_Ui
+ * @ingroup Efl_Ui_Win_Move_Resize_Mode
  */
 typedef enum
 {
-  EFL_UI_WIN_MOVE_RESIZE_MODE_MOVE = 1, /**< Start moving window */
+  EFL_UI_WIN_MOVE_RESIZE_MODE_MOVE = 1, /**< Start moving window
+                                         *
+                                         * @since 1.22 */
   EFL_UI_WIN_MOVE_RESIZE_MODE_TOP = 2 /* 1 >> 1 */, /**< Start resizing window
-                                                     * to the top */
+                                                     * to the top
+                                                     *
+                                                     * @since 1.22 */
   EFL_UI_WIN_MOVE_RESIZE_MODE_BOTTOM = 4 /* 1 >> 2 */, /**< Start resizing
                                                         * window to the bottom
-                                                        */
+                                                        *
+                                                        * @since 1.22 */
   EFL_UI_WIN_MOVE_RESIZE_MODE_LEFT = 8 /* 1 >> 3 */, /**< Start resizing window
-                                                      * to the left */
+                                                      * to the left
+                                                      *
+                                                      * @since 1.22 */
   EFL_UI_WIN_MOVE_RESIZE_MODE_RIGHT = 16 /* 1 >> 4 */ /**< Start resizing window
-                                                       * to the right */
+                                                       * to the right
+                                                       *
+                                                       * @since 1.22 */
 } Efl_Ui_Win_Move_Resize_Mode;
 
 
 #endif
-/** Efl UI window class
+/** Efl UI window class.
  *
  * @since 1.22
  *
@@ -187,7 +206,7 @@ typedef enum
  */
 #define EFL_UI_WIN_CLASS efl_ui_win_class_get()
 
-EWAPI const Efl_Class *efl_ui_win_class_get(void);
+EWAPI const Efl_Class *efl_ui_win_class_get(void) EINA_CONST;
 
 /**
  * @brief In some environments you may have an indicator that shows battery
@@ -230,7 +249,7 @@ EOAPI Efl_Ui_Win_Indicator_Mode efl_ui_win_indicator_mode_get(const Eo *obj);
 
 #ifdef EFL_BETA_API_SUPPORT
 /**
- * @brief Sets the keyboard mode of the window.
+ * @brief The keyboard mode of the window.
  *
  * @param[in] obj The object.
  * @param[in] mode The mode, one of @ref Efl_Ui_Win_Keyboard_Mode.
@@ -244,7 +263,7 @@ EOAPI void efl_ui_win_keyboard_mode_set(Eo *obj, Efl_Ui_Win_Keyboard_Mode mode);
 
 #ifdef EFL_BETA_API_SUPPORT
 /**
- * @brief Get the keyboard mode of the window.
+ * @brief The keyboard mode of the window.
  *
  * @param[in] obj The object.
  *
@@ -348,10 +367,10 @@ EOAPI void efl_ui_win_screen_constrain_set(Eo *obj, Eina_Bool constrain);
 
 #ifdef EFL_BETA_API_SUPPORT
 /**
- * @brief Get the constraints on the maximum width and height of a window
- * relative to the width and height of the screen.
+ * @brief Constrain the maximum width and height of a window to the width and
+ * height of the screen.
  *
- * When this function returns @c true, @c obj will never resize larger than the
+ * When @c constrain is @c true, @c obj will never resize larger than the
  * screen.
  *
  * @param[in] obj The object.
@@ -499,7 +518,7 @@ EOAPI void efl_ui_win_exit_on_close_set(Eo *obj, const Eina_Value *exit_code);
 EOAPI const Eina_Value *efl_ui_win_exit_on_close_get(const Eo *obj);
 
 /**
- * @brief Set a window object's icon.
+ * @brief A window object's icon.
  *
  * This sets an image to be used as the icon for the given window, in the
  * window manager decoration part. The exact pixel dimensions of the object
@@ -519,10 +538,15 @@ EOAPI const Eina_Value *efl_ui_win_exit_on_close_get(const Eo *obj);
 EOAPI void efl_ui_win_icon_object_set(Eo *obj, Efl_Canvas_Object *icon);
 
 /**
- * @brief Get the icon object used for the window.
+ * @brief A window object's icon.
  *
- * The object returns is the one marked by @ref efl_ui_win_icon_object_set as
- * the object to use for the window icon.
+ * This sets an image to be used as the icon for the given window, in the
+ * window manager decoration part. The exact pixel dimensions of the object
+ * (not object size) will be used and the image pixels will be used as-is when
+ * this function is called. If the image object has been updated, then call
+ * this function again to source the image pixels and place them in the
+ * window's icon. Note that only objects of type @ref Efl_Canvas_Image or
+ * @ref Efl_Ui_Image are allowed.
  *
  * @param[in] obj The object.
  *
@@ -535,7 +559,7 @@ EOAPI void efl_ui_win_icon_object_set(Eo *obj, Efl_Canvas_Object *icon);
 EOAPI const Efl_Canvas_Object *efl_ui_win_icon_object_get(const Eo *obj);
 
 /**
- * @brief Set the minimized state of a window.
+ * @brief The minimized state of a window.
  *
  * @param[in] obj The object.
  * @param[in] state If @c true, the window is minimized.
@@ -547,7 +571,7 @@ EOAPI const Efl_Canvas_Object *efl_ui_win_icon_object_get(const Eo *obj);
 EOAPI void efl_ui_win_minimized_set(Eo *obj, Eina_Bool state);
 
 /**
- * @brief Get the minimized state of a window.
+ * @brief The minimized state of a window.
  *
  * @param[in] obj The object.
  *
@@ -560,7 +584,7 @@ EOAPI void efl_ui_win_minimized_set(Eo *obj, Eina_Bool state);
 EOAPI Eina_Bool efl_ui_win_minimized_get(const Eo *obj);
 
 /**
- * @brief Set the maximized state of a window.
+ * @brief The maximized state of a window.
  *
  * @param[in] obj The object.
  * @param[in] maximized If @c true, the window is maximized.
@@ -572,7 +596,7 @@ EOAPI Eina_Bool efl_ui_win_minimized_get(const Eo *obj);
 EOAPI void efl_ui_win_maximized_set(Eo *obj, Eina_Bool maximized);
 
 /**
- * @brief Get the maximized state of a window.
+ * @brief The maximized state of a window.
  *
  * @param[in] obj The object.
  *
@@ -585,7 +609,7 @@ EOAPI void efl_ui_win_maximized_set(Eo *obj, Eina_Bool maximized);
 EOAPI Eina_Bool efl_ui_win_maximized_get(const Eo *obj);
 
 /**
- * @brief Set the fullscreen state of a window.
+ * @brief The fullscreen state of a window.
  *
  * @param[in] obj The object.
  * @param[in] fullscreen If @c true, the window is fullscreen.
@@ -597,7 +621,7 @@ EOAPI Eina_Bool efl_ui_win_maximized_get(const Eo *obj);
 EOAPI void efl_ui_win_fullscreen_set(Eo *obj, Eina_Bool fullscreen);
 
 /**
- * @brief Get the fullscreen state of a window.
+ * @brief The fullscreen state of a window.
  *
  * @param[in] obj The object.
  *
@@ -611,7 +635,7 @@ EOAPI Eina_Bool efl_ui_win_fullscreen_get(const Eo *obj);
 
 #ifdef EFL_BETA_API_SUPPORT
 /**
- * @brief Set the sticky state of the window.
+ * @brief The sticky state of the window.
  *
  * Hints the Window Manager that the window in @c obj should be left fixed at
  * its position even when the virtual desktop it's on moves or changes.
@@ -628,7 +652,10 @@ EOAPI void efl_ui_win_sticky_set(Eo *obj, Eina_Bool sticky);
 
 #ifdef EFL_BETA_API_SUPPORT
 /**
- * @brief Get the sticky state of the window.
+ * @brief The sticky state of the window.
+ *
+ * Hints the Window Manager that the window in @c obj should be left fixed at
+ * its position even when the virtual desktop it's on moves or changes.
  *
  * @param[in] obj The object.
  *
@@ -643,7 +670,7 @@ EOAPI Eina_Bool efl_ui_win_sticky_get(const Eo *obj);
 
 #ifdef EFL_BETA_API_SUPPORT
 /**
- * @brief Set the urgent state of a window.
+ * @brief The urgent state of a window.
  *
  * @param[in] obj The object.
  * @param[in] urgent The mode of a urgent window, one of
@@ -658,7 +685,7 @@ EOAPI void efl_ui_win_urgent_set(Eo *obj, Efl_Ui_Win_Urgent_Mode urgent);
 
 #ifdef EFL_BETA_API_SUPPORT
 /**
- * @brief Get the urgent state of a window.
+ * @brief The urgent state of a window.
  *
  * @param[in] obj The object.
  *
@@ -673,7 +700,7 @@ EOAPI Efl_Ui_Win_Urgent_Mode efl_ui_win_urgent_get(const Eo *obj);
 
 #ifdef EFL_BETA_API_SUPPORT
 /**
- * @brief Set the modal state of a window.
+ * @brief The modal state of a window.
  *
  * @param[in] obj The object.
  * @param[in] modal The mode of a window, one of @ref Efl_Ui_Win_Modal_Mode.
@@ -687,7 +714,7 @@ EOAPI void efl_ui_win_modal_set(Eo *obj, Efl_Ui_Win_Modal_Mode modal);
 
 #ifdef EFL_BETA_API_SUPPORT
 /**
- * @brief Get the modal state of a window.
+ * @brief The modal state of a window.
  *
  * @param[in] obj The object.
  *
@@ -702,7 +729,7 @@ EOAPI Efl_Ui_Win_Modal_Mode efl_ui_win_modal_get(const Eo *obj);
 
 #ifdef EFL_BETA_API_SUPPORT
 /**
- * @brief Set the borderless state of a window.
+ * @brief The borderless state of a window.
  *
  * This function requests the Window Manager not to draw any decoration around
  * the window.
@@ -719,7 +746,10 @@ EOAPI void efl_ui_win_borderless_set(Eo *obj, Eina_Bool borderless);
 
 #ifdef EFL_BETA_API_SUPPORT
 /**
- * @brief Get the borderless state of a window.
+ * @brief The borderless state of a window.
+ *
+ * This function requests the Window Manager not to draw any decoration around
+ * the window.
  *
  * @param[in] obj The object.
  *
@@ -740,7 +770,8 @@ EOAPI Eina_Bool efl_ui_win_borderless_get(const Eo *obj);
  * @ref efl_ui_win_type_get and @ref efl_ui_win_name_get this can be changed at
  * runtime.
  *
- * Set the role of the window.
+ * The returned string is an internal one and should not be freed or modified.
+ * It will also be invalid if a new role is set or if the window is destroyed.
  *
  * @param[in] obj The object.
  * @param[in] role The role to set.
@@ -760,8 +791,6 @@ EOAPI void efl_ui_win_role_set(Eo *obj, const char *role);
  * @ref efl_ui_win_type_get and @ref efl_ui_win_name_get this can be changed at
  * runtime.
  *
- * Get the role of the window.
- *
  * The returned string is an internal one and should not be freed or modified.
  * It will also be invalid if a new role is set or if the window is destroyed.
  *
@@ -786,8 +815,6 @@ EOAPI const char *efl_ui_win_role_get(const Eo *obj);
  *
  * @note Once set, it cannot be modified afterwards.
  *
- * Name can only be set before finalize.
- *
  * @param[in] obj The object.
  * @param[in] name Window name
  *
@@ -828,7 +855,7 @@ EOAPI const char *efl_ui_win_name_get(const Eo *obj);
  *
  * @note Once set, it cannot be modified afterward.
  *
- * Type can on be set before finalize.
+ * If the object is not window object, returns @ref EFL_UI_WIN_TYPE_UNKNOWN.
  *
  * @param[in] obj The object.
  * @param[in] type Window type
@@ -851,7 +878,7 @@ EOAPI void efl_ui_win_type_set(Eo *obj, Efl_Ui_Win_Type type);
  *
  * @note Once set, it cannot be modified afterward.
  *
- * If the object is not window object, returns @c unknown.
+ * If the object is not window object, returns @ref EFL_UI_WIN_TYPE_UNKNOWN.
  *
  * @param[in] obj The object.
  *
@@ -958,9 +985,6 @@ EOAPI void efl_ui_win_accel_preference_set(Eo *obj, const char *accel);
  * Note that this option may be overriden by environment variables or the
  * configuration option "accel_preference_override".
  *
- * This will return the value of "accel_preference" when the window was
- * created.
- *
  * @param[in] obj The object.
  *
  * @return Acceleration
@@ -973,7 +997,7 @@ EOAPI const char *efl_ui_win_accel_preference_get(const Eo *obj);
 #endif /* EFL_BETA_API_SUPPORT */
 
 /**
- * @brief Set the alpha channel state of a window.
+ * @brief The alpha channel state of a window.
  *
  * If @c alpha is true, the alpha channel of the canvas will be enabled
  * possibly making parts of the window completely or partially transparent.
@@ -996,7 +1020,17 @@ EOAPI const char *efl_ui_win_accel_preference_get(const Eo *obj);
 EOAPI void efl_ui_win_alpha_set(Eo *obj, Eina_Bool alpha);
 
 /**
- * @brief Get the alpha channel state of a window.
+ * @brief The alpha channel state of a window.
+ *
+ * If @c alpha is true, the alpha channel of the canvas will be enabled
+ * possibly making parts of the window completely or partially transparent.
+ * This is also subject to the underlying system supporting it, for example a
+ * system using a compositing manager.
+ *
+ * @note Alpha window can be enabled automatically by window theme style's
+ * property. If "alpha" data.item is "1" or "true" in window style(eg.
+ * elm/win/base/default), the window is switched to alpha automatically without
+ * the explicit api call.
  *
  * @param[in] obj The object.
  *
@@ -1035,7 +1069,7 @@ EOAPI const char *efl_ui_win_stack_id_get(const Eo *obj);
 
 #ifdef EFL_BETA_API_SUPPORT
 /**
- * @brief Set the window stack ID to use as the master top-level.
+ * @brief The window stack ID to use as the master top-level.
  *
  * This sets the ID string to be used as the master top-level window as the
  * base of a stack of windows. This must be set before the first time the
@@ -1054,7 +1088,11 @@ EOAPI void efl_ui_win_stack_master_id_set(Eo *obj, const char *id);
 
 #ifdef EFL_BETA_API_SUPPORT
 /**
- * @brief Get the stack master Id that has been set.
+ * @brief The window stack ID to use as the master top-level.
+ *
+ * This sets the ID string to be used as the master top-level window as the
+ * base of a stack of windows. This must be set before the first time the
+ * window is shown and should never be changed afterwards.
  *
  * @param[in] obj The object.
  *
@@ -1352,8 +1390,8 @@ EOAPI Eina_Size2D efl_ui_win_hint_step_get(const Eo *obj);
  * object of type @ref Efl_Input_Pointer.
  *
  * Each finger in a multi touch environment can then be identified by the
- * @ref efl_input_pointer_tool_get property. The order of the pointers in this
- * iterator is not defined.
+ * @ref efl_input_pointer_touch_id_get property. The order of the pointers in
+ * this iterator is not defined.
  *
  * @note If the input surface supports hovering input, some pointers may not be
  * in a "down" state. To retrieve the list of such pointers, set the @c hover
@@ -1370,16 +1408,16 @@ EOAPI Eina_Size2D efl_ui_win_hint_step_get(const Eo *obj);
  *
  * @ingroup Efl_Ui_Win
  */
-EOAPI Eina_Iterator *efl_ui_win_pointer_iterate(const Eo *obj, Eina_Bool hover);
+EOAPI Eina_Iterator *efl_ui_win_pointer_iterate(const Eo *obj, Eina_Bool hover) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 #endif /* EFL_BETA_API_SUPPORT */
 
 #ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief The rotation of this window
  *
- * The value will automatically change when the WM of this window changes its
- * rotation. This rotation is automatically applied to all @ref Efl_Ui_Layout
- * objects.
+ * The value will automatically change when the Window Manager of this window
+ * changes its rotation. This rotation is automatically applied to all
+ * @ref Efl_Ui_Layout objects.
  *
  * @param[in] obj The object.
  * @param[in] rotation The rotation of the window
@@ -1395,9 +1433,9 @@ EOAPI void efl_ui_win_rotation_set(Eo *obj, int rotation);
 /**
  * @brief The rotation of this window
  *
- * The value will automatically change when the WM of this window changes its
- * rotation. This rotation is automatically applied to all @ref Efl_Ui_Layout
- * objects.
+ * The value will automatically change when the Window Manager of this window
+ * changes its rotation. This rotation is automatically applied to all
+ * @ref Efl_Ui_Layout objects.
  *
  * @param[in] obj The object.
  *
@@ -1411,16 +1449,12 @@ EOAPI int efl_ui_win_rotation_get(const Eo *obj);
 #endif /* EFL_BETA_API_SUPPORT */
 
 /**
- * @brief Whether focus highlight is enabled or not.
+ * @brief Whether focus highlight is enabled or not on this window, regardless
+ * of the global setting.
  *
  * See also @ref efl_ui_win_focus_highlight_style_get. See also
  * @ref efl_ui_win_focus_highlight_animate_get.
  *
- * Set the enabled status for the focus highlight in a window.
- *
- * This function will enable or disable the focus highlight, regardless of the
- * global setting for it.
- *
  * @param[in] obj The object.
  * @param[in] enabled The enabled value for the highlight.
  *
@@ -1431,13 +1465,12 @@ EOAPI int efl_ui_win_rotation_get(const Eo *obj);
 EOAPI void efl_ui_win_focus_highlight_enabled_set(Eo *obj, Eina_Bool enabled);
 
 /**
- * @brief Whether focus highlight is enabled or not.
+ * @brief Whether focus highlight is enabled or not on this window, regardless
+ * of the global setting.
  *
  * See also @ref efl_ui_win_focus_highlight_style_get. See also
  * @ref efl_ui_win_focus_highlight_animate_get.
  *
- * Get the enabled value of the focus highlight for this window.
- *
  * @param[in] obj The object.
  *
  * @return The enabled value for the highlight.
@@ -1491,10 +1524,6 @@ EOAPI const char *efl_ui_win_focus_highlight_style_get(const Eo *obj);
  * See also @ref efl_ui_win_focus_highlight_style_get. See also
  * @ref efl_ui_win_focus_highlight_enabled_get.
  *
- * Set the animate status for the focus highlight for this window.
- *
- * This function will enable or disable the animation of focus highlight.
- *
  * @param[in] obj The object.
  * @param[in] animate The enabled value for the highlight animation.
  *
@@ -1510,8 +1539,6 @@ EOAPI void efl_ui_win_focus_highlight_animate_set(Eo *obj, Eina_Bool animate);
  * See also @ref efl_ui_win_focus_highlight_style_get. See also
  * @ref efl_ui_win_focus_highlight_enabled_get.
  *
- * Get the animate value of the focus highlight for this window.
- *
  * @param[in] obj The object.
  *
  * @return The enabled value for the highlight animation.
