@@ -13,28 +13,30 @@ typedef Eo Efl_Canvas_Polygon;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /** Low-level polygon object
  *
  * @ingroup Efl_Canvas_Polygon
  */
 #define EFL_CANVAS_POLYGON_CLASS efl_canvas_polygon_class_get()
 
-EWAPI const Efl_Class *efl_canvas_polygon_class_get(void);
+EWAPI const Efl_Class *efl_canvas_polygon_class_get(void) EINA_CONST;
 
 /**
  * @brief Adds the given point to the given evas polygon object.
  *
- * @param[in] x The X coordinate of the given point.
- * @param[in] y The Y coordinate of the given point.
+ * @param[in] obj The object.
+ * @param[in] pos A point coordinate.
  *
  * @ingroup Efl_Canvas_Polygon
  */
-EOAPI void efl_canvas_polygon_point_add(Eo *obj, int x, int y);
+EOAPI void efl_canvas_polygon_point_add(Eo *obj, Eina_Position2D pos);
 
 /** Removes all of the points from the given evas polygon object.
  *
  * @ingroup Efl_Canvas_Polygon
  */
 EOAPI void efl_canvas_polygon_points_clear(Eo *obj);
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
